/**
* Copyright (c) 2012-2013 Nokia Corporation. All rights reserved.
* Nokia and Nokia Connecting People are registered trademarks of Nokia Corporation. 
* Oracle and Java are trademarks or registered trademarks of Oracle and/or its
* affiliates. Other product and company names mentioned herein may be trademarks
* or trade names of their respective owners. 
* See LICENSE.TXT for license information.
*/

package com.nokia.example.explonoid.game;

/**
 * Defines the levels the user can play.
 */
public class Levels {

    public static final int LEVEL_COUNT = 22;
    
    /**
     * Bricks have two states. Odds need two hits, evens explode from one hit.
     * Zeros mean no brick
     */
    private static final int[][][] LEVELS = {{
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {2, 0, 4, 0, 0, 0, 4, 0, 2},
            {0, 2, 0, 4, 0, 4, 0, 2, 0},
            {0, 0, 2, 0, 4, 0, 2, 0, 0},
            {0, 0, 0, 2, 0, 2, 0, 0, 0},
            {0, 0, 0, 0, 2, 0, 0, 0, 0}},
        {
            {0, 0, 6, 6, 6, 6, 6, 0, 0},
            {0, 6, 0, 0, 0, 0, 0, 6, 0},
            {6, 0, 0, 6, 0, 6, 0, 0, 6},
            {6, 0, 0, 6, 0, 6, 0, 0, 6},
            {0, 6, 0, 0, 0, 0, 0, 6, 0},
            {0, 0, 6, 6, 6, 6, 6, 0, 0}},
        {
            {0, 0, 0, 0, 8, 0, 0, 0, 0},
            {0, 0, 0, 8, 0, 8, 0, 0, 0},
            {0, 0, 0, 0, 8, 0, 0, 0, 0},
            {0, 8, 0, 0, 0, 0, 0, 8, 0},
            {8, 0, 8, 0, 0, 0, 8, 0, 8},
            {0, 8, 0, 0, 0, 0, 0, 8, 0}},
        {
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {0, 2, 2, 0, 0, 0, 2, 2, 0},
            {2, 0, 0, 2, 0, 2, 0, 0, 2},
            {2, 0, 0, 2, 0, 2, 0, 0, 2},
            {0, 2, 2, 0, 0, 0, 2, 2, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 0}},
        {
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {10, 0, 10, 0, 10, 0, 10, 0, 10},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {0, 6, 0, 6, 0, 6, 0, 6, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {2, 0, 2, 0, 2, 0, 2, 0, 2}},
        {
            {0, 6, 6, 0, 0, 0, 0, 0, 0},
            {6, 0, 0, 0, 0, 0, 0, 0, 0},
            {6, 0, 0, 0, 6, 0, 6, 0, 0},
            {6, 6, 0, 6, 0, 6, 0, 6, 0},
            {6, 0, 0, 6, 0, 6, 0, 6, 0},
            {6, 0, 0, 0, 6, 0, 6, 0, 0}},
        {
            {4, 0, 0, 0, 4, 0, 0, 0, 4},
            {4, 0, 0, 0, 4, 0, 0, 0, 4},
            {0, 4, 0, 4, 0, 4, 0, 4, 0},
            {0, 4, 0, 4, 0, 4, 0, 4, 0},
            {0, 0, 4, 0, 0, 0, 4, 0, 0},
            {0, 0, 4, 0, 0, 0, 4, 0, 0}},
        {
            {0, 0, 2, 2, 0, 0, 0, 0, 0},
            {0, 0, 2, 2, 0, 0, 0, 0, 0},
            {2, 2, 2, 2, 2, 2, 2, 2, 2},
            {2, 2, 2, 2, 2, 2, 2, 2, 2},
            {0, 0, 2, 2, 0, 0, 0, 0, 0},
            {0, 0, 2, 2, 0, 0, 0, 0, 0}},
        {
            {6, 0, 0, 0, 0, 0, 0, 0, 6},
            {6, 0, 0, 6, 6, 6, 0, 0, 6},
            {6, 0, 6, 0, 0, 0, 6, 0, 6},
            {6, 0, 6, 0, 0, 0, 6, 0, 6},
            {6, 0, 6, 0, 0, 0, 6, 0, 6},
            {6, 0, 0, 6, 6, 6, 0, 0, 6}},
        {
            {0, 0, 5, 0, 0, 0, 5, 0, 0},
            {4, 0, 5, 0, 4, 0, 5, 0, 4},
            {4, 0, 5, 0, 4, 0, 5, 0, 4},
            {4, 0, 5, 0, 4, 0, 5, 0, 4},
            {4, 0, 5, 0, 4, 0, 5, 0, 4},
            {4, 0, 0, 0, 4, 0, 0, 0, 4}},
        {
            {8, 0, 8, 0, 0, 0, 8, 0, 8},
            {0, 9, 0, 0, 0, 0, 0, 9, 0},
            {8, 0, 8, 0, 0, 0, 8, 0, 8},
            {0, 0, 0, 8, 0, 8, 0, 0, 0},
            {0, 0, 0, 0, 9, 0, 0, 0, 0},
            {0, 0, 0, 8, 0, 8, 0, 0, 0}},
        {
            {4, 4, 4, 4, 4, 4, 4, 4, 4},
            {4, 0, 0, 0, 0, 0, 0, 0, 4},
            {4, 0, 5, 0, 5, 0, 5, 0, 4},
            {4, 0, 5, 0, 5, 0, 5, 0, 4},
            {4, 0, 0, 0, 0, 0, 0, 0, 4},
            {4, 4, 4, 4, 4, 4, 4, 4, 4}},
        {
            {0, 0, 0, 10, 10, 10, 0, 0, 0},
            {0, 10, 0, 10, 0, 10, 0, 10, 0},
            {0, 0, 0, 10, 10, 10, 0, 0, 0},
            {10, 10, 10, 0, 0, 0, 10, 10, 10},
            {10, 0, 10, 0, 10, 0, 10, 0, 10},
            {10, 10, 10, 0, 0, 0, 10, 10, 10}},
        {
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {4, 4, 4, 0, 6, 0, 8, 8, 0},
            {0, 0, 4, 0, 0, 0, 8, 0, 8},
            {0, 4, 0, 0, 6, 0, 8, 0, 8},
            {4, 0, 0, 0, 6, 0, 8, 8, 0},
            {4, 4, 4, 0, 6, 0, 8, 0, 0}},
        {
            {7, 7, 7, 7, 7, 7, 7, 7, 7},
            {0, 7, 0, 7, 0, 7, 0, 7, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {0, 7, 0, 7, 0, 7, 0, 7, 0},
            {7, 7, 7, 7, 7, 7, 7, 7, 7}},
        {
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {6, 2, 6, 2, 6, 2, 6, 2, 6},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {2, 6, 2, 6, 2, 6, 2, 6, 2},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {1, 1, 1, 1, 1, 1, 1, 1, 1}},
        {
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {3, 0, 0, 0, 3, 0, 0, 0, 3},
            {0, 3, 0, 3, 0, 3, 0, 3, 0},
            {0, 0, 3, 0, 0, 0, 3, 0, 0},
            {0, 3, 0, 3, 0, 3, 0, 3, 0},
            {3, 0, 0, 0, 3, 0, 0, 0, 3}},
        {
            {6, 6, 6, 0, 0, 0, 6, 6, 6},
            {6, 6, 6, 0, 0, 0, 6, 6, 6},
            {0, 0, 0, 5, 5, 5, 0, 0, 0},
            {0, 0, 0, 5, 5, 5, 0, 0, 0},
            {6, 6, 6, 0, 0, 0, 6, 6, 6},
            {6, 6, 6, 0, 0, 0, 6, 6, 6}},
        {
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {1, 1, 0, 1, 1, 0, 1, 1, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {0, 3, 3, 0, 3, 3, 0, 3, 3},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {5, 0, 5, 5, 0, 5, 5, 0, 5}},
        {
            {9, 9, 9, 9, 9, 9, 9, 9, 9},
            {9, 9, 9, 9, 9, 9, 9, 9, 9},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {10, 10, 10, 10, 10, 10, 10, 10, 10},
            {10, 10, 10, 10, 10, 10, 10, 10, 10}},
        {
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {7, 0, 7, 0, 7, 0, 7, 0, 7},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {0, 5, 0, 5, 0, 5, 0, 5, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 0},
            {1, 0, 1, 0, 1, 0, 1, 0, 1}},
        {
            {0, 0, 0, 1, 1, 0, 0, 1, 1},
            {0, 0, 1, 0, 0, 1, 0, 0, 0},
            {0, 0, 1, 1, 1, 0, 0, 0, 0},
            {0, 0, 1, 0, 0, 0, 0, 0, 0},
            {0, 0, 1, 0, 0, 1, 0, 0, 0},
            {0, 0, 0, 1, 1, 0, 0, 0, 0}}
    };

    public static int[][] getLevel(int level) {
        return LEVELS[level - 1];
    }
}
